# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2023-05-31)


## v0.1.0 (2023-05-31)
### Feature
* **demo:** Changed template so less has to be changed when copying repo ([`fad7a3c`](https://github.com/educationwarehouse/edwh-demo-tasks-plugin/commit/fad7a3c1a811b06f0004db9974d472edf0e42858))

### Fix
* **urls:** The plugin is now simply called edwh-demo-plugin, but the github repo is not! ([`4a7b13e`](https://github.com/educationwarehouse/edwh-demo-tasks-plugin/commit/4a7b13e6245b93500b24fc48e7497fcaac6a1c08))
* **template:** Removed 'tasks' so 'demo' can be ctrl-r replaced with the actual plugin name ([`e0ddbe0`](https://github.com/educationwarehouse/edwh-demo-tasks-plugin/commit/e0ddbe098810f8a9fdb32b8d78c646bd7cb4d490))
* **changelog:** Add placeholder string ([`9dbc19d`](https://github.com/educationwarehouse/edwh-demo-tasks-plugin/commit/9dbc19dfda3b794218270ef94a439c847734ff2c))

### Documentation
* **toml:** Change default repo URLs ([`16a0e50`](https://github.com/educationwarehouse/edwh-demo-tasks-plugin/commit/16a0e5066790cf4a7adfc87bc1ec080145883069))